@@ -3,7 +3,7 @@ package Acme::PERLANCAR::Dummy::ModuleFeatures::Module1;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-25'; # DATE
 our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -23,12 +23,38 @@ Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 - A module
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-02-25.
+This document describes version 0.005 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-02-25.
 
 =head1 DESCRIPTION
 
 This is a dummy module for testing.
 
+=head1 DECLARED FEATURES
+
+Features declared by this module (actually declared in L<Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures>):
+
+=head2 From feature set Dummy
+
+Features from feature set L<Dummy|Module::Features::Dummy> declared by this module:
+
+=over
+
+=item * feature1
+
+Value: yes.
+
+=item * feature2
+
+Value: yes.
+
+=item * feature3
+
+Value: "b".
+
+=back
+
+For more details on module features, see L<Module::Features>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Acme-PERLANCAR-Dummy>.
